@@ -505,7 +505,7 @@ weightedmean_helper <- function(x,random.effects=TRUE,
                                 from=NA,to=NA,levels=NA,clabel="",
                                 rect.col=c("#00FF0080","#FF000080"),
                                 outlier.col="#00FFFF80",type=4,
-                                cutoff.76=1100,cutoff.disc=c(-15,5),
+                                cutoff.76=1100,cutoff.disc=list(-15,5,TRUE),
                                 sigdig=2,alpha=0.05,exterr=TRUE,
                                 ranked=FALSE,i2i=FALSE,common.Pb=1,
                                 units='',detritus=0,hide=NULL,
